aboutsummaryrefslogtreecommitdiff
path: root/util-linux/getopt.c
diff options
context:
space:
mode:
authorManuel Novoa III <mjn3@codepoet.org>2003-03-19 09:13:01 +0000
committerManuel Novoa III <mjn3@codepoet.org>2003-03-19 09:13:01 +0000
commitcad5364599eb5062d59e0c397ed638ddd61a8d5d (patch)
treea318d0f03aa076c74b576ea45dc543a5669e8e91 /util-linux/getopt.c
parente01f9662a5bd5d91be4f6b3941b57fff73cd5af1 (diff)
downloadbusybox-cad5364599eb5062d59e0c397ed638ddd61a8d5d.tar.gz
Major coreutils update.
Diffstat (limited to 'util-linux/getopt.c')
-rw-r--r--util-linux/getopt.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/util-linux/getopt.c b/util-linux/getopt.c
index e126d7b6e..25eeab69b 100644
--- a/util-linux/getopt.c
+++ b/util-linux/getopt.c
@@ -37,7 +37,7 @@
* <misiek@misiek.eu.org>)
* Ported to Busybox - Alfred M. Szmidt <ams@trillian.itslinux.org>
* Removed --version/-V and --help/-h in
* Removed prase_error(), using error_msg() from Busybox instead
* Replaced our_malloc with xmalloc and our_realloc with xrealloc
*
*/
@@ -95,7 +95,7 @@ const char *normalize(const char *arg)
free(BUFFER);
if (!quote) { /* Just copy arg */
- BUFFER=xstrdup(arg);
+ BUFFER=bb_xstrdup(arg);
return BUFFER;
}
@@ -224,7 +224,7 @@ void add_longopt(const char *name,int has_arg)
long_options[long_options_nr-1].has_arg=has_arg;
long_options[long_options_nr-1].flag=NULL;
long_options[long_options_nr-1].val=LONG_OPT;
- long_options[long_options_nr-1].name=xstrdup(name);
+ long_options[long_options_nr-1].name=bb_xstrdup(name);
}
long_options_nr++;
}
@@ -254,7 +254,7 @@ void add_long_options(char *options)
arg_opt=required_argument;
}
if (tlen == 0)
- error_msg("empty long option after -l or --long argument");
+ bb_error_msg("empty long option after -l or --long argument");
}
add_longopt(tokptr,arg_opt);
}
@@ -273,7 +273,7 @@ void set_shell(const char *new_shell)
else if (!strcmp(new_shell,"csh"))
shell=TCSH;
else
- error_msg("unknown shell after -s or --shell argument");
+ bb_error_msg("unknown shell after -s or --shell argument");
}
@@ -322,7 +322,7 @@ int getopt_main(int argc, char *argv[])
printf(" --\n");
return 0;
} else
- error_msg_and_die("missing optstring argument");
+ bb_error_msg_and_die("missing optstring argument");
}
if (argv[1][0] != '-' || compatible) {
@@ -340,14 +340,14 @@ int getopt_main(int argc, char *argv[])
break;
case 'o':
free(optstr);
- optstr=xstrdup(optarg);
+ optstr=bb_xstrdup(optarg);
break;
case 'l':
add_long_options(optarg);
break;
case 'n':
free(name);
- name=xstrdup(optarg);
+ name=bb_xstrdup(optarg);
break;
case 'q':
quiet_errors=1;
@@ -364,14 +364,14 @@ int getopt_main(int argc, char *argv[])
quote=0;
break;
default:
- show_usage();
+ bb_show_usage();
}
if (!optstr) {
if (optind >= argc)
- error_msg_and_die("missing optstring argument");
+ bb_error_msg_and_die("missing optstring argument");
else {
- optstr=xstrdup(argv[optind]);
+ optstr=bb_xstrdup(argv[optind]);
optind++;
}
}
@@ -37,7 +37,7 @@
* Ported to Busybox - Alfred M. Szmidt <ams@trillian.itslinux.org>
* Removed --version/-V and --help/-h in
- * Removed prase_error(), using error_msg() from Busybox instead
+ * Removed prase_error(), using bb_error_msg() from Busybox instead
* Replaced our_malloc with xmalloc and our_realloc with xrealloc
*